<?php

require_once 'vendor/autoload.php';
require_once 'config.php';
require_once 'helpers.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

$mailer = new PHPMailer(true);

try {
    if (!$json = json_decode(file_get_contents('php://input'), true)) throw new Exception("There is nothing here.");

    if (!$json["key"]) throw new Exception("What's the code word?");

    if (!in_array($json["key"], $API_KEYS)) throw new Exception("Who are you?");

    if ($json["htmlurl"] && !checkURL($json["htmlurl"])) throw new Exception("Your HTML URL isn't working.");
    if ($json["texturl"] && !checkURL($json["texturl"])) throw new Exception("Your text URL isn't working.");

    $html = ($json["html"] ? $json["html"] : ($json["htmlurl"] ? file_get_contents($json["htmlurl"]) : null));
    $text = ($json["text"] ? $json["text"] : ($json["texturl"] ? file_get_contents($json["texturl"]) : null));

    foreach ($json["placeholders"] as $placeholder) {
        $html = str_replace("{".strtoupper($placeholder["name"])."}", $placeholder["value"], $html);
        $text = str_replace("{".strtoupper($placeholder["name"])."}", $placeholder["value"], $text);
    }

    $mailer->isSMTP();
    $mailer->Host = $MAIL_HOST;
    $mailer->SMTPAuth = (bool) $MAIL_USER;
    $mailer->Username = $MAIL_USER;
    $mailer->Password = $MAIL_PASS;
    $mailer->SMTPSecure = ($MAIL_STARTTLS ? PHPMailer::ENCRYPTION_STARTTLS : ($MAIL_SMTPS ? PHPMailer::ENCRYPTION_SMTPS : false));
    $mailer->Port = ($MAIL_PORT ? $MAIL_PORT : ($MAIL_SMTPS ? 465 : 587));
    $mailer->XMailer = "Kumi Systems Mailer 0.1 (https://kumi.systems/)";

    $mailer->setFrom(($MAIL_FROM_MAIL ? $MAIL_FROM_MAIL : $MAIL_USER), $MAIL_FROM_NAME);

    foreach ($json["recipients"] as $recipient) $mailer->addAddress($recipient["email"], $recipient["name"]);
    foreach ($json["ccs"] as $cc) $mailer->addCC($cc["email"], $cc["name"]);
    foreach ($json["bccs"] as $bcc) $mailer->addBCC($bcc["email"], $bcc["name"]);

    foreach ($ALWAYS_TO as $recipient) $mailer->addAddress($recipient);
    foreach ($ALWAYS_CC as $cc) $mailer->addCC($cc);
    foreach ($ALWAYS_BCC as $bcc) $mailer->addBCC($bcc);

    $mailer->isHTML((bool) $html);
    $mailer->Subject = $json["subject"];
    $mailer->Body = ($html ? $html : $text);
    $mailer->AltBody = ($html ? $text : null);

    foreach ($json["attachments"] as $attachment) {
        $tempfile = tempnam(sys_get_temp_dir(), "EXPMAIL_");
        file_put_contents($tempfile, file_get_contents($attachment["url"]));
        $filename = ($attachment["filename"] ? $attachment["filename"] : getFilename($attachment["url"]));
        $mailer->addAttachment($tempfile, $filename);
    }

    $mailer->send();

    $response = array(
        "status" => "success"
    );

} catch (Exception $e) {
    $response = array(
        "status" => "error",
        "error" => "{$e->getMessage()}"
    );
};

echo json_encode($response);
